[fdo-commits] r2530 - trunk/Fdo/Unmanaged/Inc/Fdo/Xml
svn_fdo at osgeo.org
svn_fdo at osgeo.org
Thu Feb 15 15:03:41 EST 2007
Author: gregboone
Date: 2007-02-15 15:03:41 -0500 (Thu, 15 Feb 2007)
New Revision: 2530
Modified:
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/ClassMapping.h
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/ClassMappingCollection.h
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/Context.h
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/Deserializable.h
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/ElementMapping.h
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/ElementMappingCollection.h
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureContext.h
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureFlags.h
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureHandler.h
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeaturePropertyReader.h
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeaturePropertyWriter.h
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureReader.h
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureWriter.h
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/Flags.h
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/NameCollectionHandler.h
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/SchemaMapping.h
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/SpatialContextFlags.h
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/SpatialContextReader.h
trunk/Fdo/Unmanaged/Inc/Fdo/Xml/SpatialContextWriter.h
Log:
FDO4: API - Update API documentation included in the FDO header files
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/ClassMapping.h
===================================================================
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/ClassMapping.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/ClassMapping.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -45,6 +45,8 @@
/// set when the type represents geometries and indicates what kind of geometries the type
/// represents. wkBaseName must be L"" or one of the constants defined in
/// commonGml212Gml212.h.
+ /// \param wkSchemaName
+ /// Well-known schema name.
///
/// \return
/// Returns FdoXmlClassMapping
@@ -90,6 +92,7 @@
FDO_API FdoXmlElementMappingCollection* GetElementMappings();
/// \cond DOXYGEN-IGNORE
+
/// \brief
/// Writes this XML Class Mapping to XML. Called when
/// the element is serialized to XML.
@@ -108,8 +111,8 @@
);
/// \endcond
+/// \cond DOXYGEN-IGNORE
protected:
-/// \cond DOXYGEN-IGNORE
FdoXmlClassMapping() {}
FdoXmlClassMapping(
@@ -148,6 +151,7 @@
FdoXmlElementMappingsP mElementMappings;
};
+/// \ingroup (typedefs)
/// \brief
/// FdoXmlClassMappingP is a FdoPtr on FdoXmlClassMapping, provided for convenience.
typedef FdoPtr<FdoXmlClassMapping> FdoXmlClassMappingP;
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/ClassMappingCollection.h
===================================================================
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/ClassMappingCollection.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/ClassMappingCollection.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -55,6 +55,7 @@
/// \endcond
};
+/// \ingroup (typedefs)
/// \brief
/// FdoXmlClassMappingsP is a FdoPtr on FdoXmlClassMappingCollection, provided for convenience.
typedef FdoPtr<FdoXmlClassMappingCollection> FdoXmlClassMappingsP;
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/Context.h
===================================================================
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/Context.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/Context.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -30,19 +30,31 @@
/// \brief
/// Constructs a context for parsing FDO Deserializable items
///
- /// \param schemas
- /// Read the Feature Schemas into this collection.
+ /// \param flags
+ /// Input flags.
+ ///
+ /// \param xmlReader
+ /// Input xmlReader.
///
+ /// \return
+ /// Returns FdoXmlContext.
FDO_API static FdoXmlContext* Create( FdoXmlFlags* flags, FdoXmlReader* xmlReader );
/// \brief
/// Decodes any element name that was encoded to be XML-compatible.
///
+ /// \param name
+ /// Input name.
+ ///
+ /// \return
+ /// Returns FdoStringP.
FDO_API FdoStringP DecodeName ( FdoStringP name );
/// \brief
/// Retrieves the current XML flags.
///
+ /// \return
+ /// Returns FdoXmlFlags.
FDO_API FdoXmlFlags* GetFlags();
@@ -56,6 +68,9 @@
FdoXmlFlagsP mFlags;
};
+/// \ingroup (typedefs)
+/// \brief
+/// FdoXmlContextP is an FdoPtr on FdoXmlContext provided for convenience.
typedef FdoPtr<FdoXmlContext> FdoXmlContextP;
#endif
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/Deserializable.h
===================================================================
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/Deserializable.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/Deserializable.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -46,7 +46,7 @@
/// \brief
/// Reads an XML document from an XML reader.
///
- /// \param reader
+ /// \param xmlReader
/// Input the XML reader.
/// \param flags
/// Input controls the reading of the elements from the document.
@@ -60,7 +60,7 @@
/// \brief
/// Reads an XML document from a text reader.
///
- /// \param reader
+ /// \param textReader
/// Input the text reader. Must be positioned at the
/// start of an XML document.
/// \param flags
@@ -75,7 +75,7 @@
/// \brief
/// Reads an XML document from a stream.
///
- /// \param reader
+ /// \param stream
/// Input the stream. Must be positioned at the
/// start of an XML document.
/// \param flags
@@ -135,9 +135,9 @@
FDO_API virtual ~FdoXmlDeserializable();
private:
- /// current XML flags
+ // current XML flags
FdoXmlFlagsP mFlags;
- /// current XML reader
+ // current XML reader
FdoXmlReaderP mInternalReader;
};
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/ElementMapping.h
===================================================================
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/ElementMapping.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/ElementMapping.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -107,7 +107,7 @@
/// \brief
/// Sets the namespace URI for this element.
///
- /// \param schemaName
+ /// \param gmlUri
/// Input a URI. Defaults to the targetNamespace
/// for the schema containing this element.
///
@@ -126,7 +126,7 @@
/// \brief
/// Sets the local name for this element.
///
- /// \param schemaName
+ /// \param gmlLocalName
/// Input the local name (unprefixed name) of this
/// element. Defaults to the element name.
///
@@ -146,6 +146,7 @@
/// Functions for XML support
/// \cond DOXYGEN-IGNORE
+//
/// \brief
/// Initializes this Xml Element Mapping from its XML attributes. Called when
/// the element is deserialized from XML.
@@ -184,8 +185,8 @@
virtual void SetChoiceName(FdoString* pChoiceName){m_choiceName = pChoiceName;}
virtual FdoString* GetChoiceName(){return m_choiceName;}
+/// \cond DOXYGEN-IGNORE
protected:
-/// \cond DOXYGEN-IGNORE
FdoXmlElementMapping() {}
FdoXmlElementMapping(
@@ -207,6 +208,7 @@
FdoStringP m_choiceName;
};
+/// \ingroup (typedefs)
/// \brief
/// FdoXmlElementMappingP is a FdoPtr on FdoXmlElementMapping, provided for convenience.
typedef FdoPtr<FdoXmlElementMapping> FdoXmlElementMappingP;
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/ElementMappingCollection.h
===================================================================
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/ElementMappingCollection.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/ElementMappingCollection.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -44,8 +44,8 @@
///
FDO_API static FdoXmlElementMappingCollection* Create(FdoPhysicalElementMapping* parent);
+/// \cond DOXYGEN-IGNORE
protected:
-/// \cond DOXYGEN-IGNORE
FdoXmlElementMappingCollection() : FdoPhysicalElementMappingCollection<FdoXmlElementMapping>()
{
}
@@ -61,6 +61,7 @@
/// \endcond
};
+/// \ingroup (typedefs)
/// \brief
/// FdoXmlElementMappingsP is a FdoPtr on FdoXmlElementMappingCollection, provided for convenience.
typedef FdoPtr<FdoXmlElementMappingCollection> FdoXmlElementMappingsP;
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureContext.h
===================================================================
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureContext.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureContext.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -60,6 +60,7 @@
virtual ~FdoXmlFeatureContext();
};
+/// \ingroup (typedefs)
/// \brief
/// FdoXmlFeatureContextP is a FdoPtr on FdoXmlFeatureContext, provided for convenience.
typedef FdoPtr<FdoXmlFeatureContext> FdoXmlFeatureContextP;
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureFlags.h
===================================================================
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureFlags.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureFlags.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -58,23 +58,18 @@
class FdoXmlFeatureFlags : public FdoXmlFlags
{
public:
- /// \brief
- /// The FdoXmlFeatureFlags::ConflictOption specifies how to handle features that
- /// are already in the DataStore, when Deserializing:
- ///
- /// \param ConflictOption_Add
- /// just add new features to the FDO DataStore. If a feature already exists, an
- /// exception is thrown.
- /// \param ConflictOption_Update
- /// Update the feature if it already exists, add it if it doesn't exist. This is
- /// the slowest option, since the feature must be queried from the DataStore before
- /// it is inserted or updated.
- /// \param ConflictOption_Skip
- /// just add new features. Silently skip features already in the DataStore.
- ///
+ /// \brief
+ /// The FdoXmlFeatureFlags::ConflictOption specifies how to handle features that
+ /// are already in the DataStore, when Deserializing:
enum ConflictOption {
+ /// Add new features to the FDO DataStore and if a feature already exists,
+ /// throw an exception.
ConflictOption_Add,
+ /// Update the feature if it already exists, add it if it doesn't exist.
+ /// This is the slowest option, since the feature must be queried from the DataStore
+ /// before it is inserted or updated.
ConflictOption_Update,
+ /// Add new features and silently skip features already in the DataStore.
ConflictOption_Skip
};
@@ -121,7 +116,7 @@
/// \brief
/// Sets the write feature collection flag. This flag is initially set to true.
///
- /// \param writeMember
+ /// \param writeCollection
/// Input
/// true: The serialized features are wrapped in a GML FeatureCollection element.
/// false: features are serialize without a wrapping collection element.
@@ -322,6 +317,7 @@
};
+/// \ingroup (typedefs)
/// \brief
/// FdoXmlFeatureFlagsP is a FdoPtr on FdoXmlFeatureFlags, provided for convenience.
typedef FdoPtr<FdoXmlFeatureFlags> FdoXmlFeatureFlagsP;
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureHandler.h
===================================================================
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeaturePropertyReader.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeaturePropertyReader.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -147,6 +147,7 @@
};
+/// \ingroup (typedefs)
/// \brief
/// FdoXmlFeaturePropertyReaderP is a FdoPtr on FdoXmlFeaturePropertyReader, provided for convenience.
typedef FdoPtr<FdoXmlFeaturePropertyReader> FdoXmlFeaturePropertyReaderP;
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeaturePropertyWriter.h
===================================================================
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeaturePropertyWriter.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeaturePropertyWriter.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -81,7 +81,7 @@
/// element and the feature's actual element are written. The feature element name
/// is derived from the feature's class and schema names.
///
- /// \param stargTag
+ /// \param startTag
/// The start tag for the feature element. If it is null, the
/// feature's class name used.
///
@@ -102,7 +102,7 @@
/// \brief
/// Writes a feature property to XML.
///
- /// \param value
+ /// \param name
/// Input the property name
/// \param value
/// Input the property value as an FDO property
@@ -118,7 +118,7 @@
/// \brief
/// Writes a feature property to XML.
///
- /// \param value
+ /// \param name
/// Input the property name
/// \param value
/// Input the property value as a string
@@ -136,7 +136,7 @@
/// \brief
/// Writes a raster property to XML.
///
- /// \param value
+ /// \param name
/// Input the property name
/// \param value
/// Input the raster property value
@@ -152,7 +152,7 @@
/// \brief
/// Writes a lob property to XML.
///
- /// \param value
+ /// \param name
/// Input the property name
/// \param value
/// Input the lob property value
@@ -239,6 +239,7 @@
};
+/// \ingroup (typedefs)
/// \brief
/// FdoXmlFeaturePropertyReaderP is a FdoPtr on FdoXmlFeaturePropertyReader, provided for convenience.
typedef FdoPtr<FdoXmlFeaturePropertyWriter> FdoXmlFeaturePropertyWriterP;
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureReader.h
===================================================================
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureReader.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureReader.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -102,7 +102,7 @@
/// Normal.
/// </ul>
///
- /// \param value
+ /// \param schemas
/// Input the feature schemas
///
/// \return
@@ -112,6 +112,7 @@
};
+/// \ingroup (typedefs)
/// \brief
/// FdoXmlFeatureReaderP is a FdoPtr on FdoXmlFeatureReader, provided for convenience.
typedef FdoPtr<FdoXmlFeatureReader> FdoXmlFeatureReaderP;
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureWriter.h
===================================================================
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureWriter.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureWriter.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -103,7 +103,7 @@
/// \brief
/// Sets the class definition for the current feature being written.
///
- /// \param value
+ /// \param classDefinition
/// Input the class definition
///
/// \return
@@ -193,6 +193,7 @@
};
+/// \ingroup (typedefs)
/// \brief
/// FdoXmlFeatureWriterP is a FdoPtr on FdoXmlFeatureWriter, provided for convenience.
typedef FdoPtr<FdoXmlFeatureWriter> FdoXmlFeatureWriterP;
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/Flags.h
===================================================================
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/Flags.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/Flags.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -32,28 +32,6 @@
/// The FdoXmlFlags::ErrorLevel determines how strict the error reporting
/// is when a Feature Schema is read from an XML Document. For each errorLevel a
/// certain level of round-trip fidelity is guaranteed if the read succeeds.
- ///
- /// \param ErrorLevel_High
- /// the read fails with an exception when the
- /// Feature Schema cannot be read without alteration. If the Feature Schema
- /// is read successfully from document A and then written to document B,
- /// documents A and B are guaranteed to be identical. This errorLevel should be
- /// used when no alterations to the Feature Schema can be tolerated
- /// \param ErrorLevel_Normal
- /// fails if the Feature Schema cannot be read
- /// without changing the domain of its conforming instance documents. If the
- /// Feature Schema is read successfully from document A and then written to
- /// document B, any instance document that conforms to the document A schema
- /// will also conform to the document B schema. Any instance document that does
- /// not conform to A does not conform to B. However, documents A and B will not
- /// necessarily be identical.
- /// \param ErrorLevel_Low
- /// similar to ErrorLevel_Normal except that the
- /// instance document domain is allowed to grow. If the Feature Schema is read
- /// successfully from document A and then written to document B, any instance
- /// document that conforms to the document A schema will also conform to the
- /// document B schema. However a document that does not conform to the A schema
- /// may or may not conform to the B schema.
/// \param ErrorLevel_VeryLow
/// the read succeeds even if no level of
/// round-trip fidelity is maintained. If the Feature Schema is read successfully
@@ -65,9 +43,35 @@
/// altered during the read.
///
enum ErrorLevel {
+ /// The read fails with an exception when the Feature Schema cannot be read without alteration.
+ /// If the Feature Schema is read successfully from document A and then written to document B,
+ /// documents A and B are guaranteed to be identical.
+ /// This errorLevel should be used when no alterations to the Feature Schema can be tolerated
ErrorLevel_High,
+ /// Fails if the Feature Schema cannot be read
+ /// without changing the domain of its conforming instance documents.
+ /// If the Feature Schema is read successfully from document A
+ /// and then written to document B,
+ /// any instance document that conforms to the document A schema
+ /// will also conform to the document B schema.
+ /// Any instance document that does not conform to A does not conform to B.
+ /// However, documents A and B will not necessarily be identical.
ErrorLevel_Normal,
+ /// Similar to ErrorLevel_Normal except that the
+ /// instance document domain is allowed to grow.
+ /// If the Feature Schema is read
+ /// successfully from document A and then written to document B,
+ /// any instance document that conforms to the document A schema will also conform to the document B schema.
+ /// However a document that does not conform to the A schema
+ /// may or may not conform to the B schema.
ErrorLevel_Low,
+ /// The read succeeds even if no level of round-trip fidelity is maintained.
+ /// If the Feature Schema is read successfully from document A and then written to document B,
+ /// any instance document thatconforms to the document A schema
+ /// may or may not conform to the document B schema.
+ /// A document that does not conform to the A schema may or may not conform to the B schema.
+ /// This errorLevel is useful for reading schemas from external sources into FDO
+ /// when it doesnt matter how much the schemas are altered during the read.
ErrorLevel_VeryLow
};
@@ -113,7 +117,7 @@
/// \brief
/// Sets the error level, see FdoXmlFlags::Create().
///
- /// \param url
+ /// \param errorLevel
/// Input the error level.
///
FDO_API void SetErrorLevel( ErrorLevel errorLevel );
@@ -129,7 +133,7 @@
/// \brief
/// Sets the name adjustment flag, see FdoXmlFlags::Create().
///
- /// \param url
+ /// \param nameAdjust
/// Input the name adjustment flag.
///
FDO_API void SetNameAdjust( FdoBoolean nameAdjust );
@@ -247,6 +251,7 @@
/// \endcond
};
+/// \ingroup (typedefs)
/// \brief
/// FdoXmlFlagsP is a FdoPtr on FdoXmlFlags, provided for convenience.
typedef FdoPtr<FdoXmlFlags> FdoXmlFlagsP;
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/NameCollectionHandler.h
===================================================================
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/NameCollectionHandler.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/NameCollectionHandler.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -58,7 +58,7 @@
virtual void _writeXml(FdoXmlWriter* xmlWriter, const FdoXmlFlags* flags);
virtual FdoXmlSaxHandler* XmlStartElement(
- FdoXmlSaxContext* context,
+ FdoXmlSaxContext* saxContext,
FdoString* uri,
FdoString* name,
FdoString* qname,
@@ -66,7 +66,7 @@
);
virtual FdoBoolean XmlEndElement(
- FdoXmlSaxContext* context,
+ FdoXmlSaxContext* saxContext,
FdoString* uri,
FdoString* name,
FdoString* qname
@@ -87,6 +87,7 @@
FdoXmlSkipElementHandlerP mXmlSkipper;
};
+/// \ingroup (typedefs)
/// \brief
/// FdoXmlNameCollectionHandlerP is a FdoPtr on FdoXmlNameCollectionHandler, provided for convenience.
typedef FdoPtr<FdoXmlNameCollectionHandler> FdoXmlNameCollectionHandlerP;
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/SchemaMapping.h
===================================================================
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/SchemaMapping.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/SchemaMapping.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -97,8 +97,8 @@
///
FDO_API FdoXmlClassMappingCollection* GetClassMappings();
+/// \cond DOXYGEN-IGNORE
protected:
-/// \cond DOXYGEN-IGNORE
FdoXmlSchemaMapping() {}
FdoXmlSchemaMapping( FdoString* name );
@@ -147,6 +147,7 @@
FdoXmlClassMappingsP mClassMappings;
};
+/// \ingroup (typedefs)
/// \brief
/// FdoXmlSchemaMappingP is a FdoPtr on FdoXmlSchemaMapping, provided for convenience.
typedef FdoPtr<FdoXmlSchemaMapping> FdoXmlSchemaMappingP;
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/SpatialContextFlags.h
===================================================================
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/SpatialContextFlags.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/SpatialContextFlags.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -31,25 +31,20 @@
class FdoXmlSpatialContextFlags : public FdoXmlFlags
{
public:
- /// \brief
- /// The FdoXmlSpatialContextFlags::ConflictOption specifies how
- /// to handle Spatial Contexts that are already in the DataStore,
- /// when Deserializing:
- ///
- /// \param ConflictOption_Add
- /// just add new spatial contexts to the
- /// FDO DataStore. If the Spatial Context already exists, an exception
- /// is thrown.
- /// \param ConflictOption_Update
- /// Update the spatial context if it already
- /// exists, add it if it doesn't exist.
- /// \param ConflictOption_Skip
- /// just add new spatial contexts.
- /// Silently skip spatial contexts already in the DataStore.
- ///
+ /// \brief
+ /// The FdoXmlSpatialContextFlags::ConflictOption specifies how
+ /// to handle Spatial Contexts that are already in the DataStore,
+ /// when Deserializing:
enum ConflictOption {
+ /// Add new spatial contexts to the FDO DataStore and
+ /// if the Spatial Context already exists, throw an exception.
+ /// is thrown.
ConflictOption_Add,
+ /// Update the spatial context if it already exists and
+ /// add it if it doesn't exist.
ConflictOption_Update,
+ /// Add new spatial contexts and
+ /// silently skip spatial contexts already in the DataStore.
ConflictOption_Skip
};
@@ -139,6 +134,7 @@
FdoBoolean mIncludeDefault;
};
+/// \ingroup (typedefs)
/// \brief
/// FdoXmlSpatialContextFlagsP is a FdoPtr on FdoXmlSpatialContextFlags, provided for convenience.
typedef FdoPtr<FdoXmlSpatialContextFlags> FdoXmlSpatialContextFlagsP;
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/SpatialContextReader.h
===================================================================
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/SpatialContextReader.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/SpatialContextReader.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -118,9 +118,6 @@
/// Gets the extent of the spatial context currently being read as a byte
/// array in FGF format.
///
- /// \param length
- /// Output the length of the returned byte array.
- ///
/// \return
/// Returns the extent as a byte array in FGF format.
///
@@ -171,12 +168,12 @@
///
FDO_API virtual bool ReadNext();
- FDO_API virtual FdoXmlSaxHandler* XmlStartDocument(FdoXmlSaxContext*);
+ FDO_API virtual FdoXmlSaxHandler* XmlStartDocument(FdoXmlSaxContext* saxContext);
/// The following callbacks catch the start element and end element
/// SAX events.
FDO_API virtual FdoXmlSaxHandler* XmlStartElement(
- FdoXmlSaxContext* context,
+ FdoXmlSaxContext* saxContext,
FdoString* uri,
FdoString* name,
FdoString* qname,
@@ -184,7 +181,7 @@
);
FDO_API virtual FdoBoolean XmlEndElement(
- FdoXmlSaxContext* context,
+ FdoXmlSaxContext* saxContext,
FdoString* uri,
FdoString* name,
FdoString* qname
@@ -219,6 +216,7 @@
FdoXmlSCReadHandler* mSCHandler;
};
+/// \ingroup (typedefs)
/// \brief
/// FdoXmlSpatialContextReaderP is a FdoPtr on FdoXmlSpatialContextReader, provided for convenience.
typedef FdoPtr<FdoXmlSpatialContextReader> FdoXmlSpatialContextReaderP;
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/SpatialContextWriter.h
===================================================================
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/SpatialContextWriter.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/SpatialContextWriter.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -262,6 +262,7 @@
};
+/// \ingroup (typedefs)
/// \brief
/// FdoXmlSpatialContextWriterP is a FdoPtr on FdoXmlSpatialContextWriter, provided for convenience.
typedef FdoPtr<FdoXmlSpatialContextWriter> FdoXmlSpatialContextWriterP;
More information about the fdo-commits
mailing list
--- trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureHandler.h 2007-02-15 20:01:49 UTC (rev 2529)
+++ trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeatureHandler.h 2007-02-15 20:03:41 UTC (rev 2530)
@@ -51,7 +51,7 @@
/// Returns the feature Handler for all sub-elements of the element that was current
/// when the read started. If NULL, this feature handler remains in effect.
///
- FDO_API virtual FdoXmlFeatureHandler* FeatureDocumentStart(FdoXmlFeatureContext*);
+ FDO_API virtual FdoXmlFeatureHandler* FeatureDocumentStart(FdoXmlFeatureContext* featureContext);
/// \brief
/// Default feature handler callback that is called when the
@@ -61,7 +61,7 @@
/// \param featureContext
/// Input caller specified contextual information
///
- FDO_API virtual void FeatureDocumentEnd(FdoXmlFeatureContext*);
+ FDO_API virtual void FeatureDocumentEnd(FdoXmlFeatureContext* featureContext);
/// \brief
/// Default feature handler callback that is called when the
@@ -71,11 +71,14 @@
/// \param featureContext
/// Input caller specified contextual information
///
+ /// \param classDefinition
+ /// Input class definition.
+ ///
/// \return
/// Returns the feature Handler for the features in this collection.
/// If NULL, this feature handler remains in effect.
///
- FDO_API virtual FdoXmlFeatureHandler* FeatureCollectionStart(FdoXmlFeatureContext*,FdoClassDefinition*);
+ FDO_API virtual FdoXmlFeatureHandler* FeatureCollectionStart(FdoXmlFeatureContext* featureContext, FdoClassDefinition* classDefinition);
/// \brief
/// Default feature handler callback that is called when the
@@ -90,7 +93,7 @@
/// to continue. Return value is ignored if the current parse is not an incremental
/// parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureCollectionEnd(FdoXmlFeatureContext*);
+ FDO_API virtual FdoBoolean FeatureCollectionEnd(FdoXmlFeatureContext* featureContext);
/// \brief
/// Default feature handler callback that is called when the
@@ -106,7 +109,7 @@
/// Returns the feature Handler for the feature's properties. If NULL, this feature
/// handler remains in effect.
///
- FDO_API virtual FdoXmlFeatureHandler* FeatureStart(FdoXmlFeatureContext*,FdoClassDefinition*);
+ FDO_API virtual FdoXmlFeatureHandler* FeatureStart(FdoXmlFeatureContext* featureContext, FdoClassDefinition* classDefinition);
/// \brief
/// Default feature handler callback that is called when the
@@ -120,7 +123,7 @@
/// parse to continue. Return value is ignored if the current parse is not an
/// incremental parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureEnd(FdoXmlFeatureContext*);
+ FDO_API virtual FdoBoolean FeatureEnd(FdoXmlFeatureContext* featureContext);
/// \brief
/// Default feature handler callback that is called when the
@@ -132,15 +135,15 @@
/// Input caller specified contextual information
/// \param name
/// Input property name
/// \param name
/// Input property value
///
/// \return
/// Returning true causes the current parse to stop. Returning false causes
/// the parse to continue. Return value is ignored if the current parse is not an
/// incremental parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureProperty(FdoXmlFeatureContext*, FdoString*, FdoBoolean);
+ FDO_API virtual FdoBoolean FeatureProperty(FdoXmlFeatureContext* featureContext, FdoString* name, FdoBoolean boolPropertyValue);
/// \brief
/// Default feature handler callback that is called when the
@@ -152,15 +155,15 @@
/// Input caller specified contextual information
/// \param name
/// Input property name
/// \param name
/// Input property value
///
/// \return
/// Returning true causes the current parse to stop. Returning false causes
/// the parse to continue. Return value is ignored if the current parse is not an
/// incremental parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureProperty(FdoXmlFeatureContext*, FdoString*, FdoByte);
+ FDO_API virtual FdoBoolean FeatureProperty(FdoXmlFeatureContext* featureContext, FdoString* name, FdoByte bytePropertyValue);
/// \brief
/// Default feature handler callback that is called when the
@@ -172,15 +175,15 @@
/// Input caller specified contextual information
/// \param name
/// Input property name
- /// \param name
- /// Input property value
+ /// \param dateTimePropertyValue
+ /// Input FdoDateTime property value
///
/// \return
/// Returning true causes the current parse to stop. Returning false causes
/// the parse to continue. Return value is ignored if the current parse is not an
/// incremental parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureProperty(FdoXmlFeatureContext*, FdoString*, FdoDateTime);
+ FDO_API virtual FdoBoolean FeatureProperty(FdoXmlFeatureContext* featureContext, FdoString* name, FdoDateTime dateTimePropertyValue);
/// \brief
/// Default feature handler callback that is called when the
@@ -192,15 +195,15 @@
/// Input caller specified contextual information
/// \param name
/// Input property name
/// \param name
/// Input property value
///
/// \return
/// Returning true causes the current parse to stop. Returning false causes
/// the parse to continue. Return value is ignored if the current parse is not an
/// incremental parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureProperty(FdoXmlFeatureContext*, FdoString*, FdoDouble);
+ FDO_API virtual FdoBoolean FeatureProperty(FdoXmlFeatureContext* featureContext, FdoString* name, FdoDouble doublePropertyValue);
/// \brief
/// Default feature handler callback that is called when the
@@ -212,15 +215,15 @@
/// Input caller specified contextual information
/// \param name
/// Input property name
/// \param name
/// Input property value
///
/// \return
/// Returning true causes the current parse to stop. Returning false causes
/// the parse to continue. Return value is ignored if the current parse is not an
/// incremental parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureProperty(FdoXmlFeatureContext*, FdoString*, FdoInt16);
+ FDO_API virtual FdoBoolean FeatureProperty(FdoXmlFeatureContext* featureContext, FdoString* name, FdoInt16 int16PropertyValue);
/// \brief
/// Default feature handler callback that is called when the
@@ -232,15 +235,15 @@
/// Input caller specified contextual information
/// \param name
/// Input property name
/// \param name
/// Input property value
///
/// \return
/// Returning true causes the current parse to stop. Returning false causes
/// the parse to continue. Return value is ignored if the current parse is not an
/// incremental parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureProperty(FdoXmlFeatureContext*, FdoString*, FdoInt32);
+ FDO_API virtual FdoBoolean FeatureProperty(FdoXmlFeatureContext* featureContext, FdoString* name, FdoInt32 int32PropertyValue);
/// \brief
/// Default feature handler callback that is called when the
@@ -252,15 +255,15 @@
/// Input caller specified contextual information
/// \param name
/// Input property name
/// \param name
/// Input property value
///
/// \return
/// Returning true causes the current parse to stop. Returning false causes
/// the parse to continue. Return value is ignored if the current parse is not an
/// incremental parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureProperty(FdoXmlFeatureContext*, FdoString*, FdoInt64);
+ FDO_API virtual FdoBoolean FeatureProperty(FdoXmlFeatureContext* featureContext, FdoString* name, FdoInt64 int64PropertyValue);
/// \brief
/// Default feature handler callback that is called when the
@@ -272,15 +275,15 @@
/// Input caller specified contextual information
/// \param name
/// Input property name
/// \param name
/// Input property value
///
/// \return
/// Returning true causes the current parse to stop. Returning false causes
/// the parse to continue. Return value is ignored if the current parse is not an
/// incremental parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureProperty(FdoXmlFeatureContext*, FdoString*, FdoFloat);
+ FDO_API virtual FdoBoolean FeatureProperty(FdoXmlFeatureContext* featureContext, FdoString* name, FdoFloat floatPropertyValue);
/// \brief
/// Default feature handler callback that is called when the
@@ -292,15 +295,15 @@
/// Input caller specified contextual information
/// \param name
/// Input property name
/// \param name
/// Input property value
///
/// \return
/// Returning true causes the current parse to stop. Returning false causes
/// the parse to continue. Return value is ignored if the current parse is not an
/// incremental parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureProperty(FdoXmlFeatureContext*, FdoString*, FdoString*);
+ FDO_API virtual FdoBoolean FeatureProperty(FdoXmlFeatureContext* featureContext, FdoString* name, FdoString* stringPropertyValue);
/// \brief
/// Default feature handler callback that is called when the
@@ -313,7 +316,7 @@
/// Input caller specified contextual information
/// \param name
/// Input property name
- /// \param raster
+ /// \param rasterPropertyValue
/// Input raster image properties. This object always has a NULL stream reader. The image is
/// handled by the FeatureBinaryData() callback.
///
@@ -322,7 +325,7 @@
/// parse to continue. Return value is ignored if the current parse is not an
/// incremental parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureStartRasterProperty(FdoXmlFeatureContext*, FdoString*, FdoIRaster*);
+ FDO_API virtual FdoBoolean FeatureStartRasterProperty(FdoXmlFeatureContext* featureContext, FdoString* name, FdoIRaster* rasterPropertyValue);
/// \brief
/// Default feature handler callback that is called when the
@@ -337,7 +340,7 @@
/// to continue. Return value is ignored if the current parse is not an incremental
/// parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureEndRasterProperty(FdoXmlFeatureContext*);
+ FDO_API virtual FdoBoolean FeatureEndRasterProperty(FdoXmlFeatureContext* featureContext);
/// \brief
/// Default feature handler callback that is called when the
@@ -356,7 +359,7 @@
/// to continue. Return value is ignored if the current parse is not an incremental
/// parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureStartLobProperty(FdoXmlFeatureContext*, FdoString*);
+ FDO_API virtual FdoBoolean FeatureStartLobProperty(FdoXmlFeatureContext* featureContext, FdoString* name);
/// \brief
/// Default feature handler callback that is called when the
@@ -371,7 +374,7 @@
/// to continue. Return value is ignored if the current parse is not an incremental
/// parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureEndLobProperty(FdoXmlFeatureContext*);
+ FDO_API virtual FdoBoolean FeatureEndLobProperty(FdoXmlFeatureContext* featureContext);
/// \brief
/// Default feature handler callback that is called when the
@@ -382,9 +385,9 @@
/// Input caller specified contextual information
/// \param name
/// Input property name
- /// \param bytes
+ /// \param geometryByteArray
/// Input pointer to the byte array defining the geometry value
- /// \param count
+ /// \param byteCount
/// Input number of bytes in the byte array
///
/// \return
@@ -392,7 +395,7 @@
/// continue. Return value is ignored if the current parse is not an incremental
/// parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureGeometricProperty(FdoXmlFeatureContext*, FdoString*, FdoByte*, FdoInt32);
+ FDO_API virtual FdoBoolean FeatureGeometricProperty(FdoXmlFeatureContext* featureContext, FdoString*name, FdoByte* geometryByteArray, FdoInt32 byteCount);
/// \brief
/// Default feature handler callback that is called when the
@@ -410,7 +413,7 @@
/// Returns the feature Handler for the current object property's sub-properties.
/// If NULL, this feature handler remains in effect.
///
- FDO_API virtual FdoXmlFeatureHandler* FeatureStartObjectProperty(FdoXmlFeatureContext*, FdoString*, FdoClassDefinition*);
+ FDO_API virtual FdoXmlFeatureHandler* FeatureStartObjectProperty(FdoXmlFeatureContext* featureContext, FdoString* name, FdoClassDefinition* classDefinition);
/// \brief
/// Default feature handler callback that is called when the
@@ -425,7 +428,7 @@
/// to continue. Return value is ignored if the current parse is not an incremental
/// parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureEndObjectProperty(FdoXmlFeatureContext*);
+ FDO_API virtual FdoBoolean FeatureEndObjectProperty(FdoXmlFeatureContext* featureContext);
/// \brief
/// Default feature handler callback that is called when the
@@ -458,7 +461,7 @@
/// Returns the feature Handler for the current association property's sub-properties.
/// If NULL, this feature handler remains in effect.
///
- FDO_API virtual FdoXmlFeatureHandler* FeatureStartAssociationProperty(FdoXmlFeatureContext*, FdoString*, FdoClassDefinition*);
+ FDO_API virtual FdoXmlFeatureHandler* FeatureStartAssociationProperty(FdoXmlFeatureContext* featureContext, FdoString* name, FdoClassDefinition* classDefinition);
/// \brief
/// Default feature handler callback that is called when the
@@ -473,7 +476,7 @@
/// to continue. Return value is ignored if the current parse is not an incremental
/// parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureEndAssociationProperty(FdoXmlFeatureContext*);
+ FDO_API virtual FdoBoolean FeatureEndAssociationProperty(FdoXmlFeatureContext* featureContext);
/// \brief
/// Default Feature Handle callback that is called when the FdoXmlFeaturePropertyReader
@@ -492,7 +495,7 @@
/// to continue. Return value is ignored if the current parse is not an incremental
/// parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureCharacters(FdoXmlFeatureContext*, FdoString*);
+ FDO_API virtual FdoBoolean FeatureCharacters(FdoXmlFeatureContext* featureContext, FdoString* chars);
/// \brief
/// Default Feature callback that is called when the FdoXmlFeaturePropertyReader
@@ -515,7 +518,7 @@
/// to continue. Return value is ignored if the current parse is not an incremental
/// parse ( see FdoXmlFeaturePropertyReader::Parse())
///
- FDO_API virtual FdoBoolean FeatureBinaryData(FdoXmlFeatureContext*, FdoByte*, FdoSize);
+ FDO_API virtual FdoBoolean FeatureBinaryData(FdoXmlFeatureContext* featureContext, FdoByte* bytes, FdoSize count);
};
Modified: trunk/Fdo/Unmanaged/Inc/Fdo/Xml/FeaturePropertyReader.h
===================================================================
@@ -132,15 +135,15 @@
/// \param name
/// Input property name
- /// \param name
- /// Input property value
+ /// \param boolPropertyValue
+ /// Input value of boolean property.
///
/// \return
@@ -152,15 +155,15 @@
/// \param name
/// Input property name
- /// \param name
- /// Input property value
+ /// \param bytePropertyValue
+ /// Input byte property value
///
/// \return
@@ -192,15 +195,15 @@
/// \param name
/// Input property name
- /// \param name
- /// Input property value
+ /// \param doublePropertyValue
+ /// Input double property value
///
/// \return
@@ -212,15 +215,15 @@
/// \param name
/// Input property name
- /// \param name
- /// Input property value
+ /// \param int16PropertyValue
+ /// Input Int16 property value
///
/// \return
@@ -232,15 +235,15 @@
/// \param name
/// Input property name
- /// \param name
- /// Input property value
+ /// \param int32PropertyValue
+ /// Input Int32 property value
///
/// \return
@@ -252,15 +255,15 @@
/// \param name
/// Input property name
- /// \param name
- /// Input property value
+ /// \param int64PropertyValue
+ /// Input Int64 property value
///
/// \return
@@ -272,15 +275,15 @@
/// \param name
/// Input property name
- /// \param name
- /// Input property value
+ /// \param floatPropertyValue
+ /// Input float property value
///
/// \return
@@ -292,15 +295,15 @@
/// \param name
/// Input property name
- /// \param name
- /// Input property value
+ /// \param stringPropertyValue
+ /// Input string property value
///
/// \return